<?php
function values_board_settings_init() {
	register_setting('values_board', 'values_board_options');

	add_settings_section(
		'values_board_section_developers',
		null,
		'values_board_section_developers_cb',
		'values_board'
	);

	// register a new field in the "values_board_section_developers" section, inside the "values_board" page
	add_settings_field(
		'values_board_field_values', // as of WP 4.6 this value is used only internally
		// use $args' label_for to populate the id inside the callback
		__('Values', 'values_board'),
		'values_board_field_values_cb',
		'values_board',
		'values_board_section_developers',
		[
			'label_for' => 'values_board_field_values',
			'class' => 'values_board_row',
			'values_board_custom_data' => 'custom',
		]
	);

	add_settings_field(
		'values_board_field_colors', // as of WP 4.6 this value is used only internally
		// use $args' label_for to populate the id inside the callback
		__('Colors', 'values_board'),
		'values_board_field_colors_cb',
		'values_board',
		'values_board_section_developers',
		[
			'label_for' => 'values_board_field_colors',
			'class' => 'values_board_row',
			'values_board_custom_data' => 'custom',
		]
	);
}

add_action('admin_init', 'values_board_settings_init');

function values_board_section_developers_cb($args) {
	// HTML
}

function values_board_field_values_cb($args) {
	$options = get_option('values_board_options');
	?>

	<textarea rows="10" cols="30" id="<?php echo esc_attr($args['label_for']); ?>" name="values_board_options[<?php echo esc_attr($args['label_for']); ?>]"><?php echo $options[$args['label_for']]; ?></textarea>
	<p class="description">
		<?php esc_html_e('Enter a list of values. One per line.', 'values_board'); ?>
	</p>
	<?php
}

function values_board_field_colors_cb($args) {
	$options = get_option('values_board_options');
	?>

	<textarea rows="10" cols="15" id="<?php echo esc_attr($args['label_for']); ?>" name="values_board_options[<?php echo esc_attr($args['label_for']); ?>]"><?php echo $options[$args['label_for']]; ?></textarea>
	<p class="description">
		<?php esc_html_e('Enter a list of colors that correspond to the values above. One per line.', 'values_board'); ?>
	</p>
	<?php
}

function values_board_options_page() {
	// add top level menu page
	add_submenu_page(
		'recognitions-admin-page',
		'Settings',
		'Settings',
		'manage_options',
		'values_board',
		'values_board_options_page_html'
	);
}

add_action('admin_menu', 'values_board_options_page');

function values_board_options_page_html() {
	// check user capabilities
	if (!current_user_can('manage_options')) {
		return;
	}

	// add error/update messages

	// check if the user have submitted the settings
	// wordpress will add the "settings-updated" $_GET parameter to the url
	if (isset($_GET['settings-updated'])) {
		// add settings saved message with the class of "updated"
		add_settings_error('values_board_messages', 'values_board_message', __('Settings Saved', 'values_board'), 'updated');
	}

	// show error/update messages
	settings_errors('values_board_messages');
	?>
	<div class="wrap">
		<h1><?php echo esc_html(get_admin_page_title()); ?></h1>
		<form action="options.php" method="post">
			<?php
			// output security fields for the registered setting "values_board"
			settings_fields('values_board');
			// output setting sections and their fields
			// (sections are registered for "values_board", each field is registered to a specific section)
			do_settings_sections('values_board');
			// output save settings button
			submit_button('Save Settings');
			?>
		</form>
	</div>
<?php
}