<?php
add_action('parse_request', 'parse_values_board_request');

function parse_values_board_request() {
	global $current_user;
	$uri = strtok($_SERVER["REQUEST_URI"], '?');
	switch ($uri) {
		case '/values-board/users':
			if (!$current_user)
				return null;

			http_response_code(200);

			$users = get_users(array(
				'role' => 'author'
			));

			$returnArray = [];

			foreach ($users as $user) {
				$avatar = get_field('avatar', 'user_' . $user->ID);
				$preppedUser = array(
					'posts_per_page' => -1,
					'ID' => $user->ID,
					'display_name' => $user->data->display_name,
				);

				if ($avatar)
					$preppedUser['url'] = $avatar['url'];

				$returnArray[] = $preppedUser;
			}

			echo json_encode($returnArray);
			exit();
		case '/values-board/recognitions':
			if (!$current_user)
				return null;

			http_response_code(200);

			$recognitions = get_posts(array(
				'posts_per_page' => -1,
				'post_status' => 'any',
				'post_type' => 'recognition'
			));

			foreach ($recognitions as $i => &$recognition) {
				$fields = get_fields($recognition);
				$fields['value'] = explode(',', $fields['value']);
				$recognition->acf = $fields;
			}

			echo json_encode($recognitions);
			exit();
		case '/values-board/recognition':
			if (!$current_user || !$_POST)
				return null;

			http_response_code(200);

			$newPostId = wp_insert_post(array(
				'posts_per_page' => -1,
				'post_title' => $_POST['title'],
				'post_author' => $_POST['author'],
				'post_type' => 'recognition',
				'post_status' => 'publish'
			));

			$values = implode(',', $_POST['fields']['value']);

			update_field('note', $_POST['fields']['note'], $newPostId);
			update_field('who', $_POST['fields']['who'], $newPostId);
			update_field('value', $values, $newPostId);

			$created = get_post($newPostId);
			$created->acf = get_fields($created);
			$created->acf['value'] = $_POST['fields']['value'];

			echo json_encode($created);
			exit();
		case '/values-board/archives':
			if (!$current_user)
				return null;

			http_response_code(200);

			$recognitions = get_posts(array(
				'posts_per_page' => -1,
				'post_type' => 'recognition',
				'post_status' => 'any',
				'date_query' => array(
					array(
						'year'  => $_GET['year'],
						'month' => date('m', strtotime($_GET['month']))
					),
				),
			));

			foreach ($recognitions as $i => &$recognition) {
				$fields = get_fields($recognition);
				$recognition->acf = $fields;
			}

			echo json_encode($recognitions);
			exit();
		case '/values-board/toggle-status':
			if (!$current_user)
				return null;

			http_response_code(200);

			$id = $_GET['id'];
			$status = $_GET['status'];

			wp_update_post(array(
				'ID' => $id,
				'post_status' => $status
			));

			exit();
	}
}

add_action('parse_request', 'avatar_fetcher');

function avatar_fetcher() {
	$uri = strtok($_SERVER["REQUEST_URI"],'?');
	if (strstr($uri, '/get-avatar-image')) {
		$args = explode('/', $uri);
		$uid = array_pop($args);

		$dir = getcwd();

		$avatarImg = get_avatar($uid);

		preg_match('/src="(.*?)"/i', $avatarImg, $matches);
		$avatarUrl = $matches[1];

		header('Location: '. $avatarUrl);
		exit();
	}
}
?>